@@ -20,17 +20,14 @@ class pipeline:
         self.heatmap=heatmap
         self.out_flag=out_flag
 
-    def producer(self,): 
+    def producer(self,epoch): 
         self.batch_data=data.args_init(self.batch_size,self.out_h,self.out_w,self.image_dir,\
             self.label_dir,self.file_name,self.label_name,self.image_type,self.label_type,self.label_postfix,\
                 self.heatmap, self.shuffle,self.thread_num,self.out_flag)
-        data.start_producer(self.batch_data)
-    def consumer(self,i):
+        data.start_producer(self.batch_data,epoch)
         batch_size = self.batch_data.get_batch_size()
         epoch_size = self.batch_data.get_epoch_size()
-
-        if((i+1)*batch_size>epoch_size):
-            return None
+        return int(epoch_size/batch_size)
+    def consumer(self,):
         batch=data.next_batch_detection()
-        return [batch.images,batch.box_labels]
-
+        return [batch.images,batch.box_labels]
\ No newline at end of file
